#
# Constants for Gtkinter
#

# true/false
FALSE = 0
TRUE  = 1

# GtkAccelFlag's
ACCEL_VISIBLE        = 1 << 0
ACCEL_SIGNAL_VISIBLE = 1 << 1
ACCEL_LOCKED         = 1 << 2
ACCEL_MASK           = 0x07

# GtkArrowType's
ARROW_UP    = 0
ARROW_DOWN  = 1
ARROW_LEFT  = 2
ARROW_RIGHT = 3

# GtkAttachOptions
EXPAND = 1 << 0
SHRINK = 1 << 1
FILL   = 1 << 2

# GtkButtonBoxStyle's
BUTTONBOX_DEFAULT_STYLE = 0
BUTTONBOX_SPREAD        = 1
BUTTONBOX_EDGE          = 2
BUTTONBOX_START         = 3
BUTTONBOX_END           = 4

# GtkCurveType's
CURVE_TYPE_LINEAR = 0
CURVE_TYPE_SPLINE = 1
CURVE_TYPE_FREE   = 2

# GtkDirectionType's
DIR_TAB_FORWARD  = 0
DIR_TAB_BACKWARD = 1
DIR_UP           = 2
DIR_DOWN         = 3
DIR_LEFT         = 4
DIR_RIGHT        = 5

# GtkJustification's
JUSTIFY_LEFT   = 0
JUSTIFY_RIGHT  = 1
JUSTIFY_CENTER = 2
JUSTIFY_FILL   = 3

# GtkMatchType's
MATCH_ALL      = 0
MATCH_ALL_TAIL = 1
MATCH_HEAD     = 2
MATCH_TAIL     = 3
MATCH_EXACT    = 4
MATCH_LAST     = 5

# GtkMenuFactoryType's
MENU_FACTORY_MENU        = 0
MENU_FACTORY_MENU_BAR    = 1
MENU_FACTORY_OPTION_MENU = 2

# GtkMetricType's
PIXELS      = 0
INCHES      = 1
CENTIMETERS = 2

# GtkOrientation's
ORIENTATION_HORIZONTAL = 0
ORIENTATION_VERTICAL   = 1

# GtkPackType's
PACK_START = 0
PACK_END   = 1

# GtkPathPriorityType's
PATH_PRIO_LOWEST      = 0
PATH_PRIO_GTK         = 4
PATH_PRIO_APPLICATION = 8
PATH_PRIO_RC          = 12
PATH_PRIO_HIGHEST     = 15
PATH_PRIO_MASK        = 0x0f

# GtkPathType's
PATH_WIDGET       = 0
PATH_WIDGET_CLASS = 1
PATH_CLASS        = 2

# GtkPolicyType's
POLICY_ALWAYS    = 0
POLICY_AUTOMATIC = 1

# GtkPositionType's
POS_LEFT   = 0
POS_RIGHT  = 1
POS_TOP    = 2
POS_BOTTOM = 3

# GtkPreviewType's
PREVIEW_COLOR     = 0
PREVIEW_GRAYSCALE = 1

# GtkReliefStyle's
RELIEF_NORMAL = 0
RELIEF_HALF   = 1
RELIEF_NONE   = 2

# GtkResizeMode's
RESIZE_PARENT    = 0
RESIZE_QUEUE     = 1
RESIZE_IMMEDIATE = 2

# GtkScrollType's
SCROLL_NONE          = 0
SCROLL_STEP_BACKWARD = 1
SCROLL_STEP_FORWARD  = 2
SCROLL_PAGE_BACKWARD = 3
SCROLL_PAGE_FORWARD  = 4
SCROLL_JUMP          = 5

# GtkSelectionMode's
SELECTION_SINGLE   = 0
SELECTION_BROWSE   = 1
SELECTION_MULTIPLE = 2
SELECTION_EXTENDED = 3

# GtkShadowType's
SHADOW_NONE       = 0
SHADOW_IN         = 1
SHADOW_OUT        = 2
SHADOW_ETCHED_IN  = 3
SHADOW_ETCHED_OUT = 4

# GtkStateType's
STATE_NORMAL      = 0
STATE_ACTIVE      = 1
STATE_PRELIGHT    = 2
STATE_SELECTED    = 3
STATE_INSENSITIVE = 4

# GtkSubmenuDirection's
DIRECTION_LEFT  = 0
DIRECTION_RIGHT = 1

# GtkSubmenuPlacement's
TOP_BOTTOM = 0
LEFT_RIGHT = 1

# GtkToolbarStyle's
TOOLBAR_ICONS = 0
TOOLBAR_TEXT  = 1
TOOLBAR_BOTH  = 2

# GtkTroughType's
TROUGH_NONE  = 0
TROUGH_START = 1
TROUGH_END   = 2
TROUGH_JUMP  = 3

# GtkUpdateType's
UPDATE_CONTINUOUS    = 0
UPDATE_DISCONTINUOUS = 1
UPDATE_DELAYED       = 2

# GtkVisibility's
VISIBILITY_NONE    = 0
VISIBILITY_PARTIAL = 1
VISIBILITY_FULL    = 2

# GtkWindowPosition's
WIN_POS_NONE   = 0
WIN_POS_CENTER = 1
WIN_POS_MOUSE  = 2

# GtkWindowType's
WINDOW_TOPLEVEL = 0
WINDOW_DIALOG   = 1
WINDOW_POPUP    = 2

# GtkObjectFlag's
DESTROYED  = 1 << 0
FLOATING   = 1 << 1
CONNECTED  = 1 << 2
RESERVED_2 = 1 << 3
# GtkWidgetFlag's
TOPLEVEL         = 1 << 4
NO_WINDOW        = 1 << 5
REALIZED         = 1 << 6
MAPPED           = 1 << 7
VISIBLE          = 1 << 8
SENSITIVE        = 1 << 9
PARENT_SENSITIVE = 1 << 10
CAN_FOCUS        = 1 << 11
HAS_FOCUS        = 1 << 12
CAN_DEFAULT      = 1 << 13
HAS_DEFAULT      = 1 << 14
HAS_GRAB         = 1 << 15
RC_STYLE         = 1 << 16
BASIC            = 1 << 17

# GtkCellType's
CELL_EMPTY   = 0
CELL_TEXT    = 1
CELL_PIXMAP  = 2
CELL_PIXTEXT = 3
CELL_WIDGET  = 4

# GtkCTreePos's
CTREE_POS_BEFORE   = 0
CTREE_POS_AS_CHILD = 1
CTREE_POS_AFTER    = 2

# GtkCTreeLineStyle's
CTREE_LINES_SOLID  = 0
CTREE_LINES_DOTTED = 1
CTREE_LINES_TABBED = 2
CTREE_LINES_NONE   = 3

# GtkCTreeExpansionType's
CTREE_EXPANSION_EXPAND             = 0
CTREE_EXPANSION_EXPAND_RECURSIVE   = 1
CTREE_EXPANSION_COLLAPSE           = 2
CTREE_EXPANSION_COLLAPSE_RECURSIVE = 3
CTREE_EXPANSION_TOGGLE             = 4
CTREE_EXPANSION_TOGGLE_RECURSIVE   = 5

# GtkFontMetric's
PIXELS_METRIC = 0
POINTS_METRIC = 1

# GtkPackerOption's
PACK_EXPAND = 1 << 0
FILL_X      = 1 << 1
FILL_Y      = 1 << 2

# GtkSideType's
SIDE_TOP    = 0
SIDE_BOTTOM = 1
SIDE_LEFT   = 2
SIDE_RIGHT  = 3

# GtkAnchorType's
ANCHOR_CENTER     = 0
ANCHOR_NORTH      = 1
ANCHOR_NORTH_WEST = 2
ANCHOR_NORTH_EAST = 3
ANCHOR_SOUTH      = 4
ANCHOR_SOUTH_WEST = 5
ANCHOR_SOUTH_EAST = 6
ANCHOR_WEST       = 7
ANCHOR_EAST       = 8
ANCHOR_N          = ANCHOR_NORTH
ANCHOR_NW         = ANCHOR_NORTH_WEST
ANCHOR_NE         = ANCHOR_NORTH_EAST
ANCHOR_S          = ANCHOR_SOUTH
ANCHOR_SW         = ANCHOR_SOUTH_WEST
ANCHOR_SE         = ANCHOR_SOUTH_EAST
ANCHOR_W          = ANCHOR_WEST
ANCHOR_E          = ANCHOR_EAST

# GtkProgressBarStyle's
PROGRESS_CONTINUOUS = 0
PROGRESS_DISCRETE   = 1

# GtkProgressBarOrientation's
PROGRESS_LEFT_TO_RIGHT = 0
PROGRESS_RIGHT_TO_LEFT = 1
PROGRESS_BOTTOM_TO_TOP = 2
PROGRESS_TOP_TO_BOTTOM = 3

# GtkSpinButtonUpdatePolicy's
UPDATE_ALWAYS   = 0
UPDATE_IF_VALID = 1

# GtkSpinType's
SPIN_STEP_FORWARD  = 0
SPIN_STEP_BACKWARD = 1
SPIN_PAGE_FORWARD  = 2
SPIN_PAGE_BACKWARD = 3
SPIN_HOME          = 4
SPIN_END           = 5
SPIN_USER_DEFINED  = 6

# GtkToolbarChildType's
TOOLBAR_CHILD_SPACE        = 0
TOOLBAR_CHILD_BUTTON       = 1
TOOLBAR_CHILD_TOGGLEBUTTON = 2
TOOLBAR_CHILD_RADIOBUTTON  = 3
TOOLBAR_CHILD_WIDGET       = 4

# GtkTreeViewMode's
TREE_VIEW_LINE = 0
TREE_VIEW_ITEM = 1





#!/usr/bin/env python

# translation of "Hello World III" from GTK manual, using new() function
# from Gtkinter.  Also implements a tooltip for the button.

from Gtkinter import *

def hello(*args):
	print "Hello World"
	window.destroy()

def destroy(*args):
	window.hide()
	mainquit()

tt = GtkTooltips()
tt.set_delay(500)

window = new(GtkWindow, type=WINDOW_TOPLEvEL, title="Hello World",
	     allow_grow=FALSE, allow_shrink=FALSE, border_width=10)
window.connect("destroy", destroy)

button = new(GtkButton, label="Hello World", parent=window, visible=TRUE)
button.connect("clicked", hello)

tt.set_tip(button, 'Prints "Hello World"', '')
tt.enable()

window.show()
mainloop()





"""This file describes the types defined in gtkmodule that don't have Python
class wrappers in Gtkinter, but are still used.  This module shouldn't be
imported, as it is only meant to be documentation

In this file, when I assign '_' to a variable, it represents whatever should
be in that variable."""

raise ImportError, "I told you not to import this module"

_ = None

class GtkStyle:
	"""Currently you can't assign to any of the attributes of a GtkStyle"""
	"""This type can't be instantiated directly"""

	"""COLORS"""
	black = _
	white = _
	"""These variables should be indexed with the STATE_* constants"""
	fg = (_, _, _, _, _)
	bg = (_, _, _, _, _)
	light = (_, _, _, _, _)
	dark = (_, _, _, _, _)
	mid = (_, _, _, _, _)
	text = (_, _, _, _, _)
	base = (_, _, _, _, _)

	"""The font used for text for widgets of this style"""
	font = _

	"""GC's"""
	black_gc = _
	white_gc = _
	"""These variables should be indexed with the STATE_* constants"""
	fg_gc = (_, _, _, _, _)
	bg_gc = (_, _, _, _, _)
	light_gc = (_, _, _, _, _)
	dark_gc = (_, _, _, _, _)
	mid_gc = (_, _, _, _, _)
	text_gc = (_, _, _, _, _)
	base_gc = (_, _, _, _, _)

	"""Tjese are background pixmaps for the various states"""
	bg_pixmap = (_, _, _, _, _)

	"""The colormap for this style"""
	colormap = _

class GdkColor:
	"""These are the attributes of a GdkColor:"""
	red   = _
	green = _
	blue  = _

	"""This is the pixel value for the color"""
	pixel = _

class GdkColormap:
	def __len__(self):
		"""return the size of the colormap"""
		pass
	def __getitem__(self, pos):
		"""return the GdkColor at position pos in the colormap"""
		pass
	def __getslice__(self, lo, up):
		"""return a tuple of GdkColor's according to the given slice"""
		pass
	def alloc(self, color_name):
		"""return a GdkColor matching the color name given, that has
		been allocated in the colormap"""
		pass
	def alloc(self, red, green, blue):
		"""return a GdkColor matching the 16-bit RGB values given,
		that has been allocated in the colormap"""
		pass

class GdkEvent:
	"""The type of the event -- this decides on what other attributes the
	object has"""
	type = _
	"""The GdkWindow associated with the event"""
	window = _
	send_event = _

	"""You can convert the event names to widget signal names by knocking
	off the GDK., converting to lower case, and adding '_event'."""
	if type in (GDK.NOTHING, GDK.DELETE, GDK.DESTROY, GDK.EXPOSE):
		"""No extra info for these events"""
		pass
	elif type == GDK.EXPOSE:
		"""The exposed area"""
		area = (_, _, _, _)
		count = _
	elif type == GDK.MOTION_NOTIFY:
		time = _ ; x = _ ; y = _ ; pressure = _ ; xtilt = _ ; ytilt = _
		state = _ ; is_hint = _ ; source = _ ; x_root = _ ; y_root = _
	elif type in (GDK.BUTTON_PRESS,GDK._2BUTTON_PRESS,GDK._3BUTTON_PRESS):
		time = _ ; x = _ ; y = _ ; pressure = _ ; xtilt = _ ; ytilt = _
		state = _ ; button = _ ; source = _ ; deviceid = _
		x_root = _ ; y_root = _
	elif type in (GDK.KEY_PRESS, GDK.KEY_RELEASE):
		time = _ ; keyval = _ ; string = _
	elif type in (GDK.ENTER_NOTIFY, GDK.LEAVE_NOTIFY):
		detail = _
	elif type == GDK.FOCUS_CHANGE:
		_in = _
	elif type == GDK.CONFIGURE:
		x = _ ; y = _ ; width = _ ; height = _
	elif type in (GDK.MAP, GDK.UNMAP):
		"""No extra parameters"""
		pass
	elif type == GDK.PROPERTY_NOTIFY:
		atom = _ ; time = _ ; state = _
	elif type in (GDK.SELECTION_CLEAR, GDK.SELECTION_REQUEST,
		      GDK.SELECTION_NOTIFY):
		selection = _ ; target = _ ; property = _ ; requestor = _
		time = _
	elif type in (GDK.PROXIMITY_IN, GDK.PROXIMITY_OUT):
		time = _ ; source = _ ; deviceid = _
	elif type == GDK.DRAG_BEGIN:
		protocol_version = _
	elif type == GDK.DRAG_REQUEST:
		protocol_version = _ ; sendreply = _ ; willaccept = _
		delete_data = _ ; senddata = _ ; isdrop = _
		drop_coords = (_, _) ; data_type = _ ; timestamp = _
	elif type == GDK.DROP_ENTER:
		requestor = _ ; protocol_version = _ ; sendreply = _
		extended_typelist = _
	elif type == GDK.DROP_LEAVE:
		requestor = _ ; protocol_version = _
	elif type == GDK.DROP_DATA_AVAIL:
		requestor = _ ; protocol_version = _ ; isdrop = _
		data_type = _ ; data = _ ; timestamp = _ ; coords = (_, _)
	elif type == GDK.CLIENT_EVENT:
		message_type = _ ; data_format = _ ; data = _
	elif type == GDK.VISIBILITY_NOTIFY:
		state = _
	elif type == GDK.NO_EXPOSE: pass
	elif type == GDK.OTHER_EVENT: pass
	

class GdkFont:
	""" the ascent and descent of a font"""
	ascent = _
	descent = _
	""" the font type (GDK.FONT_FONT or GDK.FONT_FONTSET) """
	type = _
	def width(str):
		"""return the width of the string"""
		pass
	def measure(str):
		"""return the width of the string, taking into account kerning
		of the final character"""
		pass


class GdkGC:
	"""GdkGC's are created with the GdkWindow.new_gc method.  It
	is impossible to directly create one."""

	"""These attributes match the parameters to GdkWindow.new_gc, and can
	be read and set"""
	foreground = _
	background = _
	font = _
	function = _
	fill = _
	tile = _
	stipple = _
	clip_mask = _
	ts_x_origin, ts_y_origin = (_, _)
	clip_x_origin, clip_y_origin = (_, _)
	graphics_exposures = _
	line_width = _
	line_style = _
	cap_style = _
	join_style = _

class GdkWindow:
	"""All attributes are read only for GdkWindow's"""
	"""The type of window -- you shouldn't need this"""
	type = _
	"""Child windows"""
	children = [_, _, '...']
	"""A GdkColormap object"""
	colormap = _
	width = _ ; height = _
	x = _     ; y = _
	"""parent windows"""
	parent = _
	toplevel = _
	"""Pointer info"""
	pointer = (_, _)
	pointer_state = _

	def new_gc(foreground=None, background=None, font=None, tile=None,
		   stipple=None, clip_mask=None, function=None, fill=None,
		   subwindow_mode=None, ts_x_origin=None, ts_y_origin=None,
		   clip_x_origin=None, clip_y_origin=None, line_width=None,
		   line_style=None, cap_style=None, join_style=None):
		"""Creates a new GC for this window with the given settings.
		The settings must be given as keyword arguments.  If a
		setting isn't given, then its default will be used"""
		pass
	
"""Aliases for GdkWindow.  GdkPixmap refers to an offscreen pixmap.
GdkDrawable refers to either a GdkWindow or a GdkPixmap"""
GdkPixmap = GdkWindow
GdkBitmap = GdkPixmap
GdkDrawable = GdkWindow
	
	
	



#!/usr/bin/env python

# translation of "Hello World III" from GTK manual, using gtk_object_new
# with gtkmodule

from _gtk import *
from _gtkbase import *
from GTK import *

def hello(*args):
	print "Hello World"
	gtk_widget_destroy(window)

def destroy(*args):
	gtk_widget_hide(window)
	gtk_main_quit()

gtk_init()
pygtk_init()

window = gtk_object_new(gtk_window_get_type(), {
	'type':            WINDOW_TOPLEVEL,
	'title':           'Hello World',
	'allow_grow':      0,
	'allow_shrink':    0,
	'border_width': 10
})
gtk_signal_connect(window, "destroy", destroy)

button = gtk_object_new(gtk_button_get_type(), {
	'label': 'Hello World',
	'parent': window,
	'visible': 1
})
gtk_signal_connect(button, "clicked", hello);

gtk_widget_show(window)
gtk_main()




#!/usr/bin/env python

# translation of "Hello World III" from gtk manual, using the new() function
# from Gtkinter

from Gtkinter import *

def hello(*args):
	print "Hello World"
	window.destroy()

def destroy(*args):
	window.hide()
	mainquit()

window = new(GtkWindow, type=WINDOW_TOPLEVEL, title='Hello World',
	     allow_grow=FALSE, allow_shrink=FALSE, border_width=10)
window.connect("destroy", destroy)

print ""
button = new(GtkButton, label="Hello World", parent=window, visible=TRUE)
button.connect("clicked", hello)

window.show_all()
mainloop()




#!/usr/bin/env python

#this is a simple translation of the scribble example that comes with GTK+

import sys
from Gtkinter import *

pixmap = None

def configure_event(widget, event):
	global pixmap
	win = widget.get_window()
	pixmap = create_pixmap(win, win.width, win.height, -1)
	draw_rectangle(pixmap, widget.get_style().white_gc, TRUE,
		       0, 0, win.width, win.height)
	return TRUE

def expose_event(widget, event):
	area = event.area
	gc = widget.get_style().fg_gc[STATE_NORMAL]
	widget.draw_pixmap(gc, pixmap, area[0], area[1], area[0], area[1],
			   area[2], area[3])
	return FALSE

def draw_brush(widget, x, y):
	rect = (x-5, y-5, 10, 10)
	draw_rectangle(pixmap, widget.get_style().black_gc, TRUE,
		       x-5, y-5, 10, 10)
	widget.queue_draw()

def button_press_event(widget, event):
	if event.button == 1 and pixmap != None:
		draw_brush(widget, event.x, event.y)
	return TRUE

def motion_notify_event(widget, event):
	if event.is_hint:
		x, y = event.window.pointer
		state = event.window.pointer_state
	else:
		x = event.x; y = event.y
		state = event.state
	if state & GDK.BUTTON1_MASK and pixmap != None:
		draw_brush(widget, x, y)
	return TRUE

def main():
	win = GtkWindow()
	win.set_name("Test Input")
	win.connect("destroy", mainquit)
	win.border_width(5)

	vbox = GtkVBox(spacing=3)
	win.add(vbox)
	vbox.show()

	drawing_area = GtkDrawingArea()
	drawing_area.size(200, 200)
	vbox.pack_start(drawing_area)
	drawing_area.show()

	drawing_area.connect("expose_event", expose_event)
	drawing_area.connect("configure_event", configure_event)
	drawing_area.connect("motion_notify_event", motion_notify_event)
	drawing_area.connect("button_press_event", button_press_event)
	drawing_area.set_events(GDK.EXPOSURE_MASK |
				GDK.LEAVE_NOTIFY_MASK |
				GDK.BUTTON_PRESS_MASK |
				GDK.POINTER_MOTION_MASK |
				GDK.POINTER_MOTION_HINT_MASK)

	button = GtkButton("Quit")
	vbox.pack_start(button, expand=FALSE, fill=FALSE)
	button.connect("clicked", win.destroy)
	button.show()
	win.show()
	mainloop()

if __name__ == '__main__':
	main()
	



#!/usr/bin/env python

# translation of "Hello World III" from GTK manual, using gtk_object_new
# with gtkmodule.  Also implements a tooltip for the button.

from _gtk import *
from _gtkbase import *
from GTK import *

def hello(*args):
	print "Hello World"
	gtk_widget_destroy(window)

def destroy(*args):
	gtk_widget_hide(window)
	gtk_main_quit()

gtk_init()
pygtk_init()

tt = gtk_tooltips_new()
gtk_tooltips_set_delay(tt, 500)

window = gtk_object_new("GtkWindow", {
	'type':         WINDOW_TOPLEVEL,
	'title':        'Hello World',
	'allow_grow':   0,
	'allow_shrink': 0,
	'border_width': 10
})
gtk_signal_connect(window, "destroy", destroy)

button = gtk_object_new("GtkButton", {
	'label':   'Hello World',
	'parent':  window,
	'visible': 1
})
gtk_signal_connect(button, "clicked", hello)

gtk_tooltips_set_tip(tt, button, 'Prints "Hello World"', '')
gtk_tooltips_enable(tt)

gtk_widget_show(window)
gtk_main()




#!/usr/bin/env python
from Gtkinter import *

# a nice easy to read fixed spacing font.
font = load_font("-*-lucidatypewriter-medium-r-*-*-14-*-*-*-*-*-*-*")

list = "abcdefghijklmnopqrstuvwxyz" + \
       "ABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
       "0123456789" + \
       "`~!@#$%^&*()-_=+\|[]{};:'\",.<>/? "
printable = ''
for c in map(chr, range(256)):
	if c in list:
		printable = printable + c
	else:
		printable = printable + '.'
del list, c

def format_line(str):
	hexstr = reduce(lambda x, a: x + hex(256+ord(a))[-2:] + ' ', str, '')
	if len(hexstr) < 48:
		hexstr = (hexstr + ' '*48)[:48]
	return hexstr + ' ' + reduce(lambda x, a: x + printable[ord(a)],str,'')

def format_data(str):
	ret = ''
	while len(str) > 16:
		line = str[:16]
		str = str[16:]
		ret = ret + format_line(line) + '\n'
	if str: ret = ret + format_line(str)
	return ret

def dnd_drop(b, event):
	data_type.set(event.data_type)
	data.delete_text(0, data.get_length())
	data.insert(font, black, white, format_data(event.data))
	pass

win = GtkWindow()
win.set_title("Drag to Me")
win.border_width(10)

t = GtkTable(5,4)
win.add(t)
t.show()

l = GtkLabel("Data Type")
l.set_justify(JUSTIFY_RIGHT)
t.attach(l, 0,1, 0,1, xoptions=FILL)
l.show()

data_type = GtkLabel("*None*")
data_type.set_justify(JUSTIFY_LEFT)
t.attach(data_type, 1,2, 0,1)
data_type.show()

l = GtkLabel("Data")
l.set_justify(JUSTIFY_RIGHT)
t.attach(l, 0,1, 1,2, xoptions=FILL)
l.show()

data = GtkText()
data.set_usize(600, -1)
style = data.get_style()
white = style.white
black = style.black
t.attach(data, 1,2, 1,2)
data.show()

win.connect("drop_data_available_event", dnd_drop)
win.dnd_drop_set(TRUE, ['text/plain', 'application/x-color', 'ALL'], FALSE)

win.connect("destroy", mainquit)
win.show()

mainloop()
